import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import 'package:minehunter/provider/data.dart';
import 'package:minehunter/ui/layout/game.dart';
import 'package:minehunter/ui/layout/parameters.dart';

class GamePage extends StatefulWidget {
  const GamePage({super.key});

  @override
  GamePageState createState() => GamePageState();
}

class GamePageState extends State<GamePage> {
  @override
  void initState() {
    super.initState();

    final Data myProvider = Provider.of<Data>(context, listen: false);
    myProvider.initParametersValues();
  }

  List<String> getImagesAssets(Data myProvider) {
    final List<String> assets = [];

    final List<String> gameImages = [
      'button_back',
      'button_start',
      'game_fail',
      'game_win',
    ];
    for (String level in myProvider.availableLevelValues) {
      gameImages.add('level_$level');
    }
    for (String size in myProvider.availableSizeValues) {
      gameImages.add('size_$size');
    }

    for (String image in gameImages) {
      assets.add('${'assets/icons/$image'}.png');
    }

    final List<String> skinImages = [
      'button_mark_mine_off',
      'button_mark_mine_on',
      'indicator_report_on',
      'indicator_report_off',
      'indicator_walk_on',
      'indicator_walk_off',
      'tile_flag_ko',
      'tile_flag_ok',
      'tile_flag',
      'tile_mine_not_found',
      'tile_mine',
      'tile_unknown',
    ];
    for (int value = 0; value < 9; value++) {
      skinImages.add('tile_$value');
    }

    for (String image in skinImages) {
      assets.add('${'assets/skins/default_$image'}.png');
    }

    assets.add('assets/skins/default_empty.png');

    return assets;
  }

  @override
  Widget build(BuildContext context) {
    final Data myProvider = Provider.of<Data>(context);

    if (!myProvider.assetsPreloaded) {
      final List<String> assets = getImagesAssets(myProvider);
      for (String asset in assets) {
        precacheImage(AssetImage(asset), context);
      }
      myProvider.updateAssetsPreloaded(true);
    }

    return SafeArea(
      child: Center(
        child: myProvider.gameIsRunning
            ? Game(myProvider: myProvider)
            : Parameters(myProvider: myProvider),
      ),
    );
  }
}
